# Let's Encrypt x Certbot

## Metadata

- **Identifier**: `lets_encrypt`
- **Maturity**: Production

### Categories

- Encryption for Web Applications

## Description

Let's Encrypt is a free, automated, and open certificate authority brought to you by the nonprofit Internet Security Research Group (ISRG). Certbot is a free, open source software tool for automatically using Let's Encrypt certificates on manually-administrated websites to enable HTTPS.

## Actions

<table>
    <thead>
        <tr>
            <th>Identifier</th>
            <th>Description</th>
            <th>Expected Parameters Keys and Types</th>
        </tr>
    </thead>
    <tbody>
        <tr>
            <td colspan="3"><center>No entry yet</center></td>
        </tr>
    </tbody>
</table>

## Information

<table>
    <thead>
        <tr>
            <th>Identifier</th>
            <th>Description</th>
            <th>Type</th>
            <th>Properties</th>
            <th>Default Value</th>
        </tr>
    </thead>
    <tbody>
        <tr>
            <td><code>domain</code></td>
            <td>The domain on which the user installs Let's Encrypt</td>
            <td><code>STRING</code></td>
            <td><code>CONFIGURATION</code>, <code>NON_DEDUCTIBLE</code>, <code>WRITABLE</code></td>
            <td></td>
        </tr>
        <tr>
            <td><code>email</code></td>
            <td>The email of the user whom installs Let's Encrypt on the given domain</td>
            <td><code>STRING</code></td>
            <td><code>CONFIGURATION</code>, <code>NON_DEDUCTIBLE</code>, <code>WRITABLE</code></td>
            <td></td>
        </tr>
        <tr>
            <td><code>log_location</code></td>
            <td>Location where Nginx logs messages</td>
            <td><code>STRING</code></td>
            <td><code>CONFIGURATION</code>, <code>MANDATORY</code>, <code>NON_DEDUCTIBLE</code>, <code>READ_ONLY</code>, <code>AUTO_GENERATED_BEFORE_INSTALL</code></td>
            <td></td>
        </tr>
        <tr>
            <td><code>revoke_reason</code></td>
            <td>The reason why Let's Encrypt has been removed. Choose from 'unspecified', 'keycompromise', 'affiliationchanged', 'superseded', 'cessationofoperation', if you wish to change the reason.</td>
            <td><code>STRING</code></td>
            <td><code>CONFIGURATION</code>, <code>OPTIONAL</code>, <code>WITH_DEFAULT_VALUE</code>, <code>NON_DEDUCTIBLE</code>, <code>WRITABLE</code></td>
            <td><code>unspecified</code></td>
        </tr>
        <tr>
            <td><code>secured_requests</code></td>
            <td>Total number of secured requests</td>
            <td><code>INTEGER</code></td>
            <td><code>METRIC</code>, <code>READ_ONLY</code></td>
            <td></td>
        </tr>
        <tr>
            <td><code>secured_requests_today</code></td>
            <td>Total number of secured requests today</td>
            <td><code>INTEGER</code></td>
            <td><code>METRIC</code>, <code>READ_ONLY</code></td>
            <td></td>
        </tr>
        <tr>
            <td><code>version</code></td>
            <td>Installed version</td>
            <td><code>STRING</code></td>
            <td><code>METRIC</code>, <code>READ_ONLY</code></td>
            <td></td>
        </tr>
    </tbody>
</table>

## Logs

<table>
    <thead>
        <tr>
            <th>Identifier</th>
            <th>Description</th>
        </tr>
    </thead>
    <tbody>
        <tr>
            <td><code>logs</code></td>
            <td>The logs generated by Let's Encrypt x Certbot for the given domain</td>
        </tr>
    </tbody>
</table>

## Tests

<table>
    <thead>
        <tr>
            <th>Identifier</th>
            <th>Description</th>
            <th>Type</th>
        </tr>
    </thead>
    <tbody>
        <tr>
            <td><code>configuration_file_presence</code></td>
            <td>Checks if the old Nginx configuration file is saved in /opt/mutablesecurity/lets_encrypt.</td>
            <td><code>PRESENCE</code></td>
        </tr>
        <tr>
            <td><code>domain_request</code></td>
            <td>Checks if the site exists before trying to generate certificate.</td>
            <td><code>REQUIREMENT</code></td>
        </tr>
        <tr>
            <td><code>internet_access</code></td>
            <td>Checks if host has Internet access.</td>
            <td><code>REQUIREMENT</code></td>
        </tr>
        <tr>
            <td><code>nginx_active</code></td>
            <td>Checks if Nginx is installed and the service is active.</td>
            <td><code>REQUIREMENT</code></td>
        </tr>
        <tr>
            <td><code>request_via_https</code></td>
            <td>Checks if the site is secured with Let's Encrypt.</td>
            <td><code>SECURITY</code></td>
        </tr>
        <tr>
            <td><code>ubuntu</code></td>
            <td>Checks if the operating system is Ubuntu.</td>
            <td><code>REQUIREMENT</code></td>
        </tr>
    </tbody>
</table>

## References

- [https://letsencrypt.org](https://letsencrypt.org)
- [https://github.com/letsencrypt](https://github.com/letsencrypt)
- [https://certbot.eff.org](https://certbot.eff.org)
- [https://github.com/certbot/certbot](https://github.com/certbot/certbot)
